==> jc-1.4.0.tar.gz: java/io/ObjectStreamClass__24InterfaceComparator.h <==
// final class java.io.ObjectStreamClass$InterfaceComparator

// class file dependencies
// @dep_class 92ef65560424daf8 java_io_ObjectStreamClass__24InterfaceComparator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_io_ObjectStreamClass__24InterfaceComparator_H_
#define _JC_java_io_ObjectStreamClass__24InterfaceComparator_H_

// Forward structure declarations
struct _jc_java_io_ObjectStreamClass__241$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_refs	_jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_refs;
typedef struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_nonrefs	_jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_nonrefs;
typedef struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$refs	_jc_java_io_ObjectStreamClass__24InterfaceComparator$refs;
typedef struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$nonrefs	_jc_java_io_ObjectStreamClass__24InterfaceComparator$nonrefs;
typedef struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$object	_jc_java_io_ObjectStreamClass__24InterfaceComparator$object;

typedef const struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$vmethods	_jc_java_io_ObjectStreamClass__24InterfaceComparator$vmethods;
typedef const struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$vtable	_jc_java_io_ObjectStreamClass__24InterfaceComparator$vtable;
typedef const struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$vtype	_jc_java_io_ObjectStreamClass__24InterfaceComparator$vtype;

// Constructors
extern void _jc_java_io_ObjectStreamClass__24InterfaceComparator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$object *);
extern void _jc_java_io_ObjectStreamClass__24InterfaceComparator$method$_init$9e3450254cd18dd9(_jc_env *, struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$object *, struct _jc_java_io_ObjectStreamClass__241$object *);

// Virtual methods
extern jint _jc_java_io_ObjectStreamClass__24InterfaceComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_io_ObjectStreamClass__24InterfaceComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_ObjectStreamClass__24InterfaceComparator$vmethods	java_io_ObjectStreamClass__24InterfaceComparator;
};

// Vtype
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$vtype {
	_jc_type			type;
	_jc_java_io_ObjectStreamClass__24InterfaceComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$refs {
    _jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_refs	java_io_ObjectStreamClass__24InterfaceComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_nonrefs	java_io_ObjectStreamClass__24InterfaceComparator;
};

// Object instance structure
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$object {
	_jc_java_io_ObjectStreamClass__24InterfaceComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_ObjectStreamClass__24InterfaceComparator$vtype	*vtype;
	_jc_java_io_ObjectStreamClass__24InterfaceComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_ObjectStreamClass__24InterfaceComparator$vtype _jc_java_io_ObjectStreamClass__24InterfaceComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_ObjectStreamClass__24InterfaceComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_ObjectStreamClass__24InterfaceComparator$class_object;

#endif	/* _JC_java_io_ObjectStreamClass__24InterfaceComparator_H_ */

==> jc-1.4.5.tar.gz: java/io/ObjectStreamClass__24InterfaceComparator.h <==
// final class java.io.ObjectStreamClass$InterfaceComparator

// class file dependencies
// @dep_class 92ef65560424daf8 java_io_ObjectStreamClass__24InterfaceComparator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_io_ObjectStreamClass__24InterfaceComparator_H_
#define _JC_java_io_ObjectStreamClass__24InterfaceComparator_H_

// Forward structure declarations
struct _jc_java_io_ObjectStreamClass__241$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_refs	_jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_refs;
typedef struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_nonrefs	_jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_nonrefs;
typedef struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$refs	_jc_java_io_ObjectStreamClass__24InterfaceComparator$refs;
typedef struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$nonrefs	_jc_java_io_ObjectStreamClass__24InterfaceComparator$nonrefs;
typedef struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$object	_jc_java_io_ObjectStreamClass__24InterfaceComparator$object;

typedef const struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$vmethods	_jc_java_io_ObjectStreamClass__24InterfaceComparator$vmethods;
typedef const struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$vtable	_jc_java_io_ObjectStreamClass__24InterfaceComparator$vtable;
typedef const struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$vtype	_jc_java_io_ObjectStreamClass__24InterfaceComparator$vtype;

// Constructors
extern void _jc_java_io_ObjectStreamClass__24InterfaceComparator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_ObjectStreamClass__24InterfaceComparator$method$_init$9e3450254cd18dd9(_jc_env *, struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$object *, struct _jc_java_io_ObjectStreamClass__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_io_ObjectStreamClass__24InterfaceComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_ObjectStreamClass__24InterfaceComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_ObjectStreamClass__24InterfaceComparator$vmethods	java_io_ObjectStreamClass__24InterfaceComparator;
};

// Vtype
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$vtype {
	_jc_type			type;
	_jc_java_io_ObjectStreamClass__24InterfaceComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$refs {
    _jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_refs	java_io_ObjectStreamClass__24InterfaceComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_ObjectStreamClass__24InterfaceComparator$sub_nonrefs	java_io_ObjectStreamClass__24InterfaceComparator;
};

// Object instance structure
struct _jc_java_io_ObjectStreamClass__24InterfaceComparator$object {
	_jc_java_io_ObjectStreamClass__24InterfaceComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_ObjectStreamClass__24InterfaceComparator$vtype	*vtype;
	_jc_java_io_ObjectStreamClass__24InterfaceComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_ObjectStreamClass__24InterfaceComparator$vtype _jc_java_io_ObjectStreamClass__24InterfaceComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_ObjectStreamClass__24InterfaceComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_ObjectStreamClass__24InterfaceComparator$class_object;

#endif	/* _JC_java_io_ObjectStreamClass__24InterfaceComparator_H_ */
